.. _predicates:

.. module:: sympy.assumptions.predicates

==========
Predicates
==========

Common
======

.. autoclass:: sympy.assumptions.predicates.common.IsTruePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.common.CommutativePredicate
   :members:

Calculus
========

.. autoclass:: sympy.assumptions.predicates.calculus.FinitePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.calculus.InfinitePredicate
   :members:

Matrix
======


.. autoclass:: sympy.assumptions.predicates.matrices.SymmetricPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.InvertiblePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.OrthogonalPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.UnitaryPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.PositiveDefinitePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.UpperTriangularPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.LowerTriangularPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.DiagonalPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.FullRankPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.SquarePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.IntegerElementsPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.RealElementsPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.ComplexElementsPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.SingularPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.NormalPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.TriangularPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.matrices.UnitTriangularPredicate
   :members:

Number Theory
=============

.. autoclass:: sympy.assumptions.predicates.ntheory.EvenPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.ntheory.OddPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.ntheory.PrimePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.ntheory.CompositePredicate
   :members:

Order
=====

.. autoclass:: sympy.assumptions.predicates.order.PositivePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.order.NegativePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.order.ZeroPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.order.NonZeroPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.order.NonPositivePredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.order.NonNegativePredicate
   :members:

Sets
====

.. autoclass:: sympy.assumptions.predicates.sets.IntegerPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.RationalPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.IrrationalPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.RealPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.ExtendedRealPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.HermitianPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.ComplexPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.ImaginaryPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.AntihermitianPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.AlgebraicPredicate
   :members:

.. autoclass:: sympy.assumptions.predicates.sets.TranscendentalPredicate
   :members:
